import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { GetResolverConfigRequest, GetResolverConfigResponse } from "../models/models_0";
import { Route53ResolverClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../Route53ResolverClient";
export interface GetResolverConfigCommandInput extends GetResolverConfigRequest {
}
export interface GetResolverConfigCommandOutput extends GetResolverConfigResponse, __MetadataBearer {
}
/**
 * <p>Retrieves the behavior configuration of Route 53 Resolver behavior for a single VPC from
 * 				Amazon Virtual Private Cloud.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { Route53ResolverClient, GetResolverConfigCommand } from "@aws-sdk/client-route53resolver"; // ES Modules import
 * // const { Route53ResolverClient, GetResolverConfigCommand } = require("@aws-sdk/client-route53resolver"); // CommonJS import
 * const client = new Route53ResolverClient(config);
 * const command = new GetResolverConfigCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link GetResolverConfigCommandInput} for command's `input` shape.
 * @see {@link GetResolverConfigCommandOutput} for command's `response` shape.
 * @see {@link Route53ResolverClientResolvedConfig | config} for Route53ResolverClient's `config` shape.
 *
 */
export declare class GetResolverConfigCommand extends $Command<GetResolverConfigCommandInput, GetResolverConfigCommandOutput, Route53ResolverClientResolvedConfig> {
    readonly input: GetResolverConfigCommandInput;
    constructor(input: GetResolverConfigCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: Route53ResolverClientResolvedConfig, options?: __HttpHandlerOptions): Handler<GetResolverConfigCommandInput, GetResolverConfigCommandOutput>;
    private serialize;
    private deserialize;
}
