import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { ListResolverConfigsRequest, ListResolverConfigsResponse } from "../models/models_0";
import { Route53ResolverClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../Route53ResolverClient";
export interface ListResolverConfigsCommandInput extends ListResolverConfigsRequest {
}
export interface ListResolverConfigsCommandOutput extends ListResolverConfigsResponse, __MetadataBearer {
}
/**
 * <p>Retrieves the Resolver configurations that you have defined.
 * 			Route 53 Resolver uses the configurations to manage DNS resolution behavior for your VPCs.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { Route53ResolverClient, ListResolverConfigsCommand } from "@aws-sdk/client-route53resolver"; // ES Modules import
 * // const { Route53ResolverClient, ListResolverConfigsCommand } = require("@aws-sdk/client-route53resolver"); // CommonJS import
 * const client = new Route53ResolverClient(config);
 * const command = new ListResolverConfigsCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link ListResolverConfigsCommandInput} for command's `input` shape.
 * @see {@link ListResolverConfigsCommandOutput} for command's `response` shape.
 * @see {@link Route53ResolverClientResolvedConfig | config} for Route53ResolverClient's `config` shape.
 *
 */
export declare class ListResolverConfigsCommand extends $Command<ListResolverConfigsCommandInput, ListResolverConfigsCommandOutput, Route53ResolverClientResolvedConfig> {
    readonly input: ListResolverConfigsCommandInput;
    constructor(input: ListResolverConfigsCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: Route53ResolverClientResolvedConfig, options?: __HttpHandlerOptions): Handler<ListResolverConfigsCommandInput, ListResolverConfigsCommandOutput>;
    private serialize;
    private deserialize;
}
