import { Command as $Command } from "@aws-sdk/smithy-client";
import { Handler, HttpHandlerOptions as __HttpHandlerOptions, MetadataBearer as __MetadataBearer, MiddlewareStack } from "@aws-sdk/types";
import { UpdateResolverConfigRequest, UpdateResolverConfigResponse } from "../models/models_0";
import { Route53ResolverClientResolvedConfig, ServiceInputTypes, ServiceOutputTypes } from "../Route53ResolverClient";
export interface UpdateResolverConfigCommandInput extends UpdateResolverConfigRequest {
}
export interface UpdateResolverConfigCommandOutput extends UpdateResolverConfigResponse, __MetadataBearer {
}
/**
 * <p>Updates the behavior configuration of Route 53 Resolver behavior for a single VPC from
 * 				Amazon Virtual Private Cloud.</p>
 * @example
 * Use a bare-bones client and the command you need to make an API call.
 * ```javascript
 * import { Route53ResolverClient, UpdateResolverConfigCommand } from "@aws-sdk/client-route53resolver"; // ES Modules import
 * // const { Route53ResolverClient, UpdateResolverConfigCommand } = require("@aws-sdk/client-route53resolver"); // CommonJS import
 * const client = new Route53ResolverClient(config);
 * const command = new UpdateResolverConfigCommand(input);
 * const response = await client.send(command);
 * ```
 *
 * @see {@link UpdateResolverConfigCommandInput} for command's `input` shape.
 * @see {@link UpdateResolverConfigCommandOutput} for command's `response` shape.
 * @see {@link Route53ResolverClientResolvedConfig | config} for Route53ResolverClient's `config` shape.
 *
 */
export declare class UpdateResolverConfigCommand extends $Command<UpdateResolverConfigCommandInput, UpdateResolverConfigCommandOutput, Route53ResolverClientResolvedConfig> {
    readonly input: UpdateResolverConfigCommandInput;
    constructor(input: UpdateResolverConfigCommandInput);
    /**
     * @internal
     */
    resolveMiddleware(clientStack: MiddlewareStack<ServiceInputTypes, ServiceOutputTypes>, configuration: Route53ResolverClientResolvedConfig, options?: __HttpHandlerOptions): Handler<UpdateResolverConfigCommandInput, UpdateResolverConfigCommandOutput>;
    private serialize;
    private deserialize;
}
